package com.ims.eval.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ims.eval.dao.result.CustomException;
import com.ims.eval.dao.result.R;
import com.ims.eval.entity.Indicator;
import com.ims.eval.service.IIndicatorService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * <p>
 * 指标 前端控制器
 * </p>
 *
 * @author wang
 * @since 2023-02-26
 */
@RestController
@RequestMapping("//indicator")
public class IndicatorController {


	@Autowired
	private IIndicatorService iIndicatorService;


	/**
	 * 查询分页数据
	 *
	 * @param id            主键ID
	 * @param indicatorName 指标名称
	 * @param indicatorCede 指标编码
	 * @param binSection    业务版块
	 * @param binStage      业务阶段
	 * @param dept          部门
	 * @param company       公司
	 * @return
	 */
	//@ImsPreAuth("eval:dataDictionary:view")
	@GetMapping(value = "list")
	public R list(@RequestParam(value = "pageNum") Integer pageNum,
				  @RequestParam(value = "pageSize") Integer pageSize,
				  @RequestParam(value = "id", required = false) String id,
				  @RequestParam(value = "indicatorName", required = false) String indicatorName,
				  @RequestParam(value = "indicatorCede", required = false) String indicatorCede,
				  @RequestParam(value = "binSection", required = false) String binSection,
				  @RequestParam(value = "binStage", required = false) String binStage,
				  @RequestParam(value = "dept", required = false) String dept,
				  @RequestParam(value = "company", required = false) String company) {
		IPage<Indicator> list = iIndicatorService.list(pageNum, pageSize, id, indicatorName, indicatorCede, binSection, binStage, dept, company);
		return R.ok().data(list);
	}


	/**
	 * 查询所有数据
	 *
	 * @param id            主键ID
	 * @param indicatorName 指标名称
	 * @param indicatorCede 指标编码
	 * @param binSection    业务版块
	 * @param binStage      业务阶段
	 * @param dept          部门
	 * @param company       公司
	 * @return
	 */
	//@ImsPreAuth("eval:dataDictionary:view")
	@GetMapping(value = "listAll")
	public R listAll(
		@RequestParam(value = "id", required = false) String id,
		@RequestParam(value = "indicatorName", required = false) String indicatorName,
		@RequestParam(value = "indicatorCede", required = false) String indicatorCede,
		@RequestParam(value = "binSection", required = false) String binSection,
		@RequestParam(value = "binStage", required = false) String binStage,
		@RequestParam(value = "dept", required = false) String dept,
		@RequestParam(value = "company", required = false) String company) {
		List<Indicator> list = iIndicatorService.listAll(id, indicatorName, indicatorCede, binSection, binStage, dept, company);
		return R.ok().data(list);
	}

	/**
	 * 添加
	 *
	 * @param indicator
	 * @return
	 */

	//@ImsPreAuth("eval:dataDictionary:edit")
	@PostMapping(value = "/save")
	@ApiOperation(value = "新增(修改)", notes = "新增（修改）")
	public R addAll(@RequestBody Indicator indicator) {

		try {
			boolean b = iIndicatorService.saveOrUpdate(indicator);
			if (b) {
				return R.ok().data(b);
			} else {
				return R.error().data("保存失败！");
			}
		} catch (CustomException e){
			return R.customError(e.getMessage()).data("失败！");
		}
	}


	/**
	 * 批量删除
	 *
	 * @param ids
	 * @return
	 */
	//@ImsPreAuth("eval:dataDictionary:remove")
	@PostMapping(value = "/remove/{ids}")
	@ApiOperation(value = "删除", notes = "删除")
	public R deleteAll(@PathVariable("ids") String ids) {
		String[] strings = ids.split(",");
		boolean b = iIndicatorService.removeByIds(Arrays.asList(strings));
		if (b) {
			return R.ok().data(b);
		} else {
			return R.error().data("删除失败！");
		}
	}


}
